# Jim - A JAX-based gravitational-wave inference pipeline

In contrast to other library such as `lal`, `pycbc` and `Bilby`, `jim` does
not just aim to give you a nuke button to do your analysis. Instead, we take a
more modular approach, providing thin wrappers around other workhorses such as
`ripple` and `flowMC`, as well as example oriented documentations. We still give
you the nuke button, but more importantly you should be able to build your own
nuke button.

## Installation

`pip install jaxGW`

## Directory

Parameter estimation examples are in `example/ParameterEstimation`.

## Attribution

